unit myDDPSLTypes;

{ - from the Assembly language code -}
{;}
{; myDDPSL - A socket listener and DDP read routines to use it.  }
{;			Written by Rich Brown, Dartmouth College.}
{; }
{; This is a package of subroutines which implement a simple socket}
{; listener for DDP packets.  An application can open multiple sockets }
{; which share this socket listener.  The listener combines all the packets}
{; (for all sockets) in a single circular buffer.  An application then }
{; calls the supplied DDPRead/DDPPeek/DDPIgnore routines to process packets}
{; from the buffer.}
{;}
{;    myDDPRead - (synchronously) reads in the next DDP packet which has been }
{;				received.  myDDPRead also returns the length, source address,}
{;				destination socket, and DDPType field.  myDDPRead also }
{;				discards the packet from the buffer.}
{;}
{;    myDDPPeek - (synchronously) reads in a few of the characters of the}
{;				next packet.  myDDPPeek typically would be used to examine }
{;				the header of the next protocol layer.  myDDPPeek returns }
{;				the actual length, source address, dest socket, and DDPType.}
{;				myDDPPeek does *not* discard the packet from the input buffer: }
{;				it should be followed by a myDDPRead or myDDPIgnore to move}
{;				"past" the current packet in the socket listener's buffer.}
{;}
{;    myDDPIgnore - discards the current packet from the socket listener's }
{;				buffer.  }
{;}
{;    mySLInit - Initialize the socket listener.  Allocates a socket listener buffer }
{;				(of a length specified by the client) and sets up the pointers.}
{;}
{;	 myDDPSLGrow - Change the socket listener buffer to the indicated size.  Returns}
{;				noErr or a memory manager status if it couldn't grow as requested.}
{;}
{;    mySLQuit - release the circular buffer.  Clear the insertion pointer so}
{;				that an arriving frame won't be written off in the weeds.}
{;}
{;	 myDDPSL  - the socket listener.  Use this for opening a socket, i.e.}
{;				in Pascal;}
{;							status := DDPOpenSocket(skt, @myDDPSL);}
{}
{; Copyright 1984-1990 Trustees of Dartmouth College.  All rights reserved.}
{;}
{; This package may be freely distributed, but is not in the public domain.}
{; Dartmouth College retains the copyright.  You may use it for any purpose, }
{; provided this copyright notice is retained, and provided you do not charge }
{; more for a product which uses this code than you would have charged }
{; without it.  Questions about this distribution policy may be addressed to:}
{;}
{; 	Software Librarian}
{; 	Dartmouth College}
{; 	Kiewit Computer Center}
{; 	Hanover, NH 03755 USA}
{;__________________________________________________________________}
{}
interface

	uses
		AppleTalk;

	const
		mySLGoToTop = -1;	{ next frame is at top of circ. buff (never seen by application) }
		mySLNoData = -2;	{ no data available in the socket listener's buffer }
		mySLChksumErr = -3;	{ that packet had a checksum error }
		mySLTooShort = -4;	{ the client's buffer was too short }
		mySLShortInBuf = -5;   { DDP Socket Listener's input buffer was too short 	}
							{   to hold at least one packet.  Use myDDPSLGrow to 	}
							{	allocate a larger socket listener buffer  		}

	function myDDPRead (Buffer: Ptr;		{ pointer to the buffer }
									var BufLen: INTEGER; 	{ max/actual length of buffer }
									var SrcAddr: AddrBlock;{ source address }
									var Socket: byte; 	{ skt of the packet being returned }
									var DDPType: byte		{ DDPtype of the packet }
									): integer;

	function myDDPPeek (Buffer: Ptr;		{ pointer to the buffer }
									var BufLen: INTEGER; 	{ max/actual length of buffer }
									var SrcAddr: AddrBlock;{ source address }
									var Socket: byte; 	{ skt of the packet being returned }
									var DDPType: byte		{ DDPtype of the packet }
									): integer;

	procedure myDDPIgnore;

	function myDDPSLInit (siz: integer): integer;
	function myDDPSLGrow (siz: integer): integer;
	procedure myDDPSLQuit;
	procedure myDDPSL;

implementation

	function myDDPRead (Buffer: Ptr;		{ pointer to the buffer }
									var BufLen: INTEGER; 	{ max/actual length of buffer }
									var SrcAddr: AddrBlock;{ source address }
									var Socket: byte; 	{ skt of the packet being returned }
									var DDPType: byte		{ DDPtype of the packet }
									): integer;
	external;

	function myDDPPeek (Buffer: Ptr;		{ pointer to the buffer }
									var BufLen: INTEGER; 	{ max/actual length of buffer }
									var SrcAddr: AddrBlock;{ source address }
									var Socket: byte; 	{ skt of the packet being returned }
									var DDPType: byte		{ DDPtype of the packet }
									): integer;
	external;

	function myDDPSLInit (siz: integer): integer;
	external;
	function myDDPSLGrow (siz: integer): integer;
	external;
	procedure myDDPIgnore;
	external;
	procedure myDDPSLQuit;
	external;
	procedure myDDPSL;
	external;

end.